# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v3.14.0~6ad3b6f',
    built_at='2022-08-03 07:30:14Z',
    sha='6ad3b6f51dfc0783644ac7bb4c0787336c569f58',
    branch='HEAD',
    tag='v3.14.0',
)
